#
# spec file for package rtkit
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rtkit
Version:        0.13
Release:        7.2
Summary:        Realtime Policy and Watchdog Daemon
# The daemon itself is GPL v3 or later, the reference implementation for
# the client BSD-3-Clause
License:        BSD-3-Clause AND GPL-3.0-or-later
Group:          System/Base
URL:            https://github.com/heftig/rtkit
Source:         https://github.com/heftig/rtkit/releases/download/v%{version}/rtkit-%{version}.tar.xz
Source1:        rtkit.sysusers
Patch0:         harden_rtkit-daemon.service.patch
Patch1:         rtkit-silent-debug-messages-by-default.patch
BuildRequires:  automake
BuildRequires:  libcap-devel
BuildRequires:  pkg-config
BuildRequires:  systemd-rpm-macros
BuildRequires:  sysuser-tools
BuildRequires:  vim
BuildRequires:  xz
BuildRequires:  pkgconfig(dbus-1) >= 1.2
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(polkit-agent-1)
BuildRequires:  pkgconfig(polkit-gobject-1)
Requires:       polkit
Requires(pre):  dbus-1
%sysusers_requires

%description
RealtimeKit is a D-Bus system service that changes the scheduling policy of
user processes/threads to SCHED_RR (i.e. realtime scheduling mode) on
request. It is intended to be used as a secure mechanism to allow real-time
scheduling to be used by normal user processes.

%prep
%autosetup -p1

%build
%sysusers_generate_pre %{SOURCE1} rtkit rtkit.conf
autoreconf -fiv
export CFLAGS="%{optflags} -fPIE -Wno-format-nonliteral -Wno-format-security"
export LDFLAGS="-Wl,-z,relro,-z,now -pie"
%configure \
  --disable-silent-rules \
  --with-systemdsystemunitdir=%{_unitdir} \
  --libexecdir=%{_libexecdir}/rtkit

make %{?_smp_mflags}
./rtkit-daemon --introspect > org.freedesktop.RealtimeKit1.xml

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
%if 0%{?suse_version} < 1600
ln -sv %{_sbindir}/service %{buildroot}%{_sbindir}/rcrtkit-daemon
%endif
install -D -m 0644 org.freedesktop.RealtimeKit1.xml %{buildroot}/%{_datadir}/dbus-1/interfaces/org.freedesktop.RealtimeKit1.xml
install -Dm0644 %{SOURCE1} %{buildroot}%{_sysusersdir}/rtkit.conf

%preun
%service_del_preun rtkit-daemon.service

%pre -f rtkit.pre
%service_add_pre rtkit-daemon.service

%post
dbus-send --system --type=method_call --dest=org.freedesktop.DBus / org.freedesktop.DBus.ReloadConfig >/dev/null 2>&1 || :
%service_add_post rtkit-daemon.service

%postun
%service_del_postun rtkit-daemon.service

%files
%defattr(0644,root,root,0755)
%license GPL LICENSE
%doc README rtkit.c rtkit.h
%attr(0755,root,root) %{_sbindir}/rtkitctl
%dir %{_libexecdir}/rtkit
%dir %{_libexecdir}/rtkit/installed-tests
%dir %{_libexecdir}/rtkit/installed-tests/rtkit
%attr(0755,root,root) %{_libexecdir}/rtkit/rtkit-daemon
%{_libexecdir}/rtkit/installed-tests/rtkit/rtkit-test
%{_datadir}/dbus-1/system-services/org.freedesktop.RealtimeKit1.service
%{_datadir}/dbus-1/interfaces/org.freedesktop.RealtimeKit1.xml
%{_datadir}/polkit-1/actions/org.freedesktop.RealtimeKit1.policy
%{_datadir}/dbus-1/system.d/org.freedesktop.RealtimeKit1.conf
%{_mandir}/man8/rtkitctl.8%{ext_man}
%if 0%{?suse_version} < 1600
%{_sbindir}/rcrtkit-daemon
%endif
%{_unitdir}/rtkit-daemon.service
%{_sysusersdir}/rtkit.conf

%changelog
* Wed Jan 22 2025 Dominique Leuenberger <dimstar@opensuse.org>
- Drop rcFOO symlinks for CODE16 (jsc#PED-266).
* Fri Feb 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Fri Jun 23 2023 Jean Delvare <jdelvare@suse.com>
- rtkit-daemon: Don't log debug messages by default (bsc#1206745).
  Added patch(es):
  * rtkit-silent-debug-messages-by-default.patch
* Fri Dec 31 2021 Callum Farmer <gmbr3@opensuse.org>
- Change to using systemd-sysusers
* Tue Nov 16 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_rtkit-daemon.service.patch
* Fri May 28 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Replace systemd-devel BuildRequires with pkgconfig(libsystemd):
  allow OBS to shortcut through the systemd-mini flavors.
* Mon Mar  8 2021 Dirk Müller <dmueller@suse.com>
- update to 0.13:
  * Link to libsystemd instead of shipping a copy of sd-daemon
  * Move D-Bus policy to datadir
  * Install the D-Bus interface description
  * Other fixes accumulated over the years from various distributions
  * Add meson build files (autotools stays available for now)
  * Replace the use of as with xxd for including a file as a string, which avoids
  * some pitfalls (#15 and portability problems). The tarball contains the
  * resulting file, so xxd is not necessary when building using autotools
  * Move rtkit-daemon.service from graphical.target to multi-user.target (#12)
  * Make libsystemd an optional dependency (#13)
* Thu Nov 12 2020 Fabian Vogt <fvogt@suse.com>
- Use /var/lib/empty instead of /proc as home for the rtkit user
- Use %%license
- Commit _servicedata to avoid updating on every commit
* Wed Jul  3 2019 mliska@suse.cz
- Update to version 0.11+git.20161005:
  * Drop removed ControlGroup stanza
  * systemd: update sd-daemon.[ch]
  * build-sys: since clock_gettime() moved to libc use mq_open to check for librt
  * Pass uid of caller to polkit
  * systemd: update sd-daemon.[ch]
  * git: update gitignore
  * git: update .gitignore
  * build-sys: modernize build system
  * systemd: secure rtkit service a bit
  * systemd: update unit file a bit
- Drop rtkit-no-cpu-controlgroup.patch
- Add -Wno-format-nonliteral -Wno-format-security to optflags in order
  to prepare for -Werror of these warnings in openSUSE:Factory.
* Fri Dec  9 2016 fbui@suse.com
- Drop BR on libsystemd-daemon as rtkit uses a fancy way to reuse
  systemd code :)
* Sun May  8 2016 mpluskal@suse.com
- Add proper provides/obsoletes due to small change in versioning
* Mon Apr 18 2016 mpluskal@suse.com
- Update to version 0.11+git.20130926:
  * Pass uid of caller to polkit
  * build-sys: since clock_gettime() moved to libc use mq_open to
    check for librt
  * systemd: update sd-daemon.[ch]
- Drop upstreamed patches
  * rtkit-bnc836939.patch
  * rtkit-use-system-sd-daemon.patch
- Add _service
- Cleanup spec file with spec-cleaner
- Drop support for pre systemd ditributions
- Add rc symlink for service
- Use more strict ldflags
* Thu Jan  1 2015 meissner@suse.com
- build with PIE
* Sun Nov  9 2014 Led <ledest@gmail.com>
- fix bashism in pre script
* Thu Feb 27 2014 meissner@suse.com
- rtkit-no-cpu-controlgroup.patch: do not specify the cpu: ControlGroup,
  unsupported by systemd currently. bnc#847948
* Fri Sep 27 2013 sreeves@suse.com
- Add rtkit-bnc836939.patch
  Fix bnc#836939 - use of insecure polkit DBUS API. CVE-2013-4326
* Wed Oct 17 2012 fcrozat@suse.com
- Don't buildrequires systemd, it is pulled by
  pkgconfig(libsystemd-daemon), fixes conflict when bootstrapping
  with systemd-mini packages.
* Sun Sep 23 2012 crrodriguez@opensuse.org
- rtkit-use-system-sd-daemon.patch Use system sddaemon libs.
* Sun Sep 23 2012 crrodriguez@opensuse.org
- Update to version 0.11.x, not much has changed other
  than systemd related updates/improvements.
* Tue Dec 20 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Thu Dec  8 2011 coolo@suse.com
- fix license to be in spdx.org format
* Fri Dec  2 2011 crrodriguez@opensuse.org
- Update to version 0.10.x
  * fix annoying warning
  Failed to make ourselves RT: Invalid argument [bnc#551777]
  * activation is now done with systemd if possible
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Mon Jan 25 2010 sreeves@novell.com
- Update to version 0.5
  + By default don't demote unknown threads
- bnc#572989 - change to /bin/false
* Fri Aug 14 2009 sreeves@novell.com
- Initial package
